@@ -1,6 +1,8 @@
+=encoding utf8
+
 =head1 NAME
 
-Locale::SubCountry - convert state, province, county etc. names to/from code
+Locale::SubCountry - Convert state, province, county etc. names to/from ISO 3166-2 codes
 
 =head1 SYNOPSIS
 
@@ -62,7 +64,7 @@ Locale::SubCountry - convert state, province, county etc. names to/from code
 
 This module allows you to convert the full name for a countries administrative
 region to the code commonly used for postal addressing. The reverse lookup
-can also be done. Sub country codes are defined in "ISO 3166-2:1998,
+can also be done. Sub country codes are defined in "ISO 3166-2:2007,
 Codes for the representation of names of countries and their subdivisions".
 
 Sub countries are termed as states in the US and Australia, provinces
@@ -281,10 +283,6 @@ province and a geographical unit. Examples are:
 
 FIPS codes are not provided for all sub countries. 
 
-=head1 BUGS
-
-None known
-
 
 =head1 AUTHOR
 
@@ -305,7 +303,7 @@ TJ Mather supplied the FIPS codes and many ammendments to the sub country data
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2011 Kim Ryan. All rights reserved.
+Copyright (c) 2012 Kim Ryan. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -324,6 +322,8 @@ use Locale::SubCountry::Data;
 
 #-------------------------------------------------------------------------------
 
+our $VERSION = '1.56';
+
 package Locale::SubCountry::World;
 
 # Define all the methods for the 'world' class here. Note that because the 
@@ -381,9 +381,6 @@ sub all_codes
 
 package Locale::SubCountry;
 
-our $VERSION = '1.50';
-
-
 #-------------------------------------------------------------------------------
 # Initialization code must be run first to create global data structure.
 # Read in the list of abbreviations and full names defined in the
@@ -484,9 +481,7 @@ our $VERSION = '1.50';
                         }
                         else
                         {
-                            print "Badly formed sub country data in $country_name\n";
-                            print $current_line,"\n";
-                            die;
+                            die "Badly formed sub country data in $country_name\nData: $current_line\n";
                         }
                     }
                 }
@@ -505,9 +500,7 @@ our $VERSION = '1.50';
                 }
                 else
                 {
-                    print "Badly formed country data in $country_name\n";
-                    print $current_line,"\n";
-                    die;                    
+                    die "Badly formed country data in $country_name\nData: $current_line\n";                   
                 }
             }
         
